@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2008-2025 by Dominique Dumont.
+# This software is Copyright (c) 2015-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd::Layers;
-$Config::Model::Backend::Systemd::Layers::VERSION = '0.258.1';
+$Config::Model::Backend::Systemd::Layers::VERSION = '0.001';
 use Mouse::Role;
 
 
@@ -27,14 +27,12 @@ sub default_directories {
             '/usr/lib/systemd/user/'
         );
     }
-    elsif ($app !~ /file$/) {
+    elsif ($app eq 'systemd') {
         @layers = (
             # paths documented by systemd-system.conf man page
             '/etc/systemd/system.conf.d/',
             '/run/systemd/system.conf.d/',
             '/lib/systemd/system.conf.d/',
-            # not documented but used to symlink to real files
-            '/etc/systemd/system/',
             # path found on Debian
             '/lib/systemd/system/',
         );
@@ -45,8 +43,6 @@ sub default_directories {
 
 1;
 
-# ABSTRACT: Role that provides Systemd default directories
-
 __END__
 
 =pod
@@ -55,29 +51,11 @@ __END__
 
 =head1 NAME
 
-Config::Model::Backend::Systemd::Layers - Role that provides Systemd default directories
+Config::Model::Backend::Systemd::Layers
 
 =head1 VERSION
 
-version 0.258.1
-
-=head1 SYNOPSIS
-
- package Config::Model::Backend::Systemd ;
- extends 'Config::Model::Backend::Any';
- with 'Config::Model::Backend::Systemd::Layers';
-
-=head1 DESCRIPTION
-
-Small role to provide Systemd default directories (user or system) to
-L<Config::Model::Backend::Systemd> and L<Config::Model::Backend::Systemd::Unit>.
-
-=head1 Methods
-
-=head2 default_directories
-
-Returns a list of default directory, depending on the application used (either
-C<systemd> or C<systemd-user>.
+version 0.001
 
 =head1 AUTHOR
 
@@ -85,7 +63,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2008-2025 by Dominique Dumont.
+This software is Copyright (c) 2015-2016 by Dominique Dumont.
 
 This is free software, licensed under:
 
