@@ -1,16 +1,13 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2008-2025 by Dominique Dumont.
+# This software is Copyright (c) 2015-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-use strict;
-use warnings;
-
-return [
+[
   {
     'element' => [
       'service',
@@ -30,24 +27,14 @@ return [
         },
         'index_type' => 'string',
         'type' => 'hash'
-      },
-      'timer',
-      {
-        'cargo' => {
-          'config_class_name' => 'Systemd::Timer',
-          'type' => 'node'
-        },
-        'index_type' => 'string',
-        'type' => 'hash'
       }
     ],
-    'generated_by' => 'parse-man.pl from systemd doc',
     'name' => 'Systemd',
-    'rw_config' => {
-      'auto_create' => '1',
-      'auto_delete' => '1',
-      'backend' => 'Systemd'
-    }
+    'read_config' => [
+      {
+        'backend' => 'Systemd'
+      }
+    ]
   }
 ]
 ;
